

#### Prepare reference queries from PANTHER webservice 18.09.2013 ####
#results will be used for Unit Tests
if(F){
  library(RCurl)

  url <- 'http://www.pantherdb.org/webservices/garuda/search.jsp?keyword='
  ids <- keys(PANTHER.db,"UNIPROT")[c(50,70,65490)];ids

  fullUrl <- paste0(url,paste(ids, collapse="|"),'&listType=gene&type=getList')
  gs <- read.delim(fullUrl,stringsAsFactors=F)$Gene.Symbol

  fullUrl <- paste0(url,paste(ids, collapse="+or+"),'&listType=pathway&type=getList')
  path_acc <- read.delim(fullUrl,stringsAsFactors=F)$Pathway.Accession

  fullUrl <- paste0(url,paste(ids, collapse="+or+"),'&listType=family&type=getList')
  fam_acc <- read.delim(fullUrl,stringsAsFactors=F)$Family.Accession

  fullUrl <- paste0(url,paste(ids, collapse="+or+"),'&listType=category&type=getList')
  cat_acc <- read.delim(fullUrl,stringsAsFactors=F)$Category.Accession
}
### ###


test_structure <- function(){
  checkEquals(sort(keytypes(PANTHER.db)),sort(PANTHER.db:::.keytypes()))
  checkEquals(sort(keys(PANTHER.db)),sort(PANTHER.db:::.keys(PANTHER.db,"FAMILY_ID")))
  checkEquals(sort(columns(PANTHER.db)),sort(PANTHER.db:::.cols()))
}


test_select_vs_webquery <- function(){

  ids <- "PTHR10079"
  webquery <- sprintf("http://www.pantherdb.org/webservices/garuda/search.jsp?keyword=%s&listType=category&type=getList",ids)

	# read.delim(webquery) webquery result on 06.10.2015:
  response <- "Category Accession Category Name GO:0002376 immune system process GO:0005102 receptor binding GO:0005125 cytokine activity GO:0005126 cytokine receptor binding GO:0005488 binding GO:0005515 protein binding GO:0005576 extracellular region GO:0007154 cell communication GO:0007165 signal transduction GO:0007166 cell surface receptor signaling pathway GO:0008283 cell proliferation GO:0009987 cellular process GO:0030097 hemopoiesis GO:0030154 cell differentiation GO:0032501 multicellular organismal process GO:0032502 developmental process GO:0044707 single-multicellular organism process GO:0048731 system development GO:0050789 regulation of biological process GO:0050896 response to stimulus GO:0065007 biological regulation PC00083 cytokine PC00128 interleukin superfamily PC00207 signaling molecule"
  webquery_res <- grep("^GO:|^PC[0-9]",unlist(strsplit(response," ")),v=T)

  select_res <- sort(c(select(PANTHER.db,keys=ids,columns="GOSLIM_ID")$GOSLIM_ID,select(PANTHER.db,keys=ids,columns="CLASS_ID")$CLASS_ID))
  checkEquals(webquery_res,select_res)

  ids <- "PC00015"
  webquery <- sprintf("http://www.pantherdb.org/webservices/garuda/search.jsp?keyword=%s&listType=family&type=getList",ids)
  #read.delim(webquery)
  #webquery result on 06.10.2015:
  response <- "Family Accession Family Name PTHR11352 PROLIFERATING CELL NUCLEAR ANTIGEN PTHR11352:SF0 PROLIFERATING CELL NUCLEAR ANTIGEN PTHR11352:SF3 SUBFAMILY NOT NAMED PTHR11352:SF4 SUBFAMILY NOT NAMED "
  webquery_res <- grep("^PTHR[0-9]",unlist(strsplit(response," ")),v=T)

  select_res <- sort(select(PANTHER.db,keys=ids,columns="FAMILY_ID",keytype="CLASS_ID")$FAMILY_ID)
  checkEquals(webquery_res,select_res)

  ids <- c("A0JM86","A0JMJ1","F1PB63")

  webquery <- sprintf("http://www.pantherdb.org/webservices/garuda/search.jsp?keyword=%s&listType=pathway&type=getList",paste(ids,collapse="+or+"))
  #read.delim(webquery)
  #webquery result on 27.06.2014:
  response <- "Pathway Accession Pathway Name Author P00020 FAS signaling pathway Huaiyu Mi P00029 Huntington disease Christina Wilson P06664 Gonadotropin-releasing hormone receptor pathway - "
  webquery_res <- grep("^P[0-9]+",unlist(strsplit(response," ")),v=T)

  select_res <- sort(select(PANTHER.db,keys=ids,columns="PATHWAY_ID",keytype="UNIPROT")$PATHWAY_ID)
  checkEquals(webquery_res,select_res)

}


test_switch_species <- function(){
  #species in v1.02
  all_specs <- "ANOPHELES|ARABIDOPSIS|BOVINE|CANINE|CHICKEN|CHIMP|COELICOLOR|ECOLI|FLY|HUMAN|MALARIA|MOUSE|PIG|RAT|RHESUS|WORM|XENOPUS|YEAST|ZEBRAFISH"
  checkEquals(all_specs,pthOrganisms(PANTHER.db))
  pthOrganisms(PANTHER.db) <- "HUMAN"
  checkEquals("HUMAN",pthOrganisms(PANTHER.db))
  resetPthOrganisms(PANTHER.db)
  checkEquals(all_specs,pthOrganisms(PANTHER.db))
}
